==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/b6/b64593d9a17f8ff617a90fe781cb0912.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_2e83ff_256x240.png */
class __TwigTemplate_e61d9a3357eda4c0a923600c844ce6b0 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000IJ\000\000\000gAMA\000\000a\000\000\000 cHRM\000\000z&\000\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000pQ<\000\000,PLTE....................................................................................................):w\000\000\000ctRNS\000XG|\"2wfZNz@@efSFccaMhmzs}䁎]bp
Ιi8*y㧁Xȓد͐ǫ\000\000\000bKGD\000H\000\000\000tIME
%'E\000\000IDATx]c޻\$,'\$h\t)\$uZ7I_B\"H1iRkggdl>ٽ=Y d]زs:w/\tf@e,!A\$HW\t\000O|FMZ ' 1d9 v<AArkeN
fsanl줰.`vbVLtm)u\\vG(\"\"\"\"\"\"8sOp~P¢5{BKF|lAH־QJ,`4.&J'To2bؓlYQI<E`\t
6-XlֈVXH|#j`Eq\000>B:qџC7?xt\000v*ݹ8\000P6_dYJ7%߾A,U4IGb(\000W
pB k.b*X&kVfvZ?k\tyYaRoڨ3DOHnoH6ݩ~
qc2\"\"\"\"\"\"ⲢԎnFb9ͷJ
yj\000JxsjNev'`dU۷ķT_`'yo-/jf>%p}b%gl:`O2Lj-6.`=3`f7ֽuCl!Q8s0x\tvIi)C۷#W\t3{=`DDDDDDg
yURbE:hZ~9јfvv_촸;{%0}z\t{]\tp]\$y>aW,:tXauO<m@RHAb!w(xǰ6 =b%wzRS\t,:3﷤61!\000!!»\\a)yc\$G]?,n7sVun R(D6Cej
)
.t~age\000^z@IR@lsR\"SOaеb}+X\000o(\trX\000=Pl 9+4:Xu\tpL(jW,)l2[0hw3ЇtE#\"\"\"\".2'd2
eFC_7씮KŌ&g~>1X\\!R&HZ%!r
B
hO?pjlgkJ{=`\000\tz*& -!dd\000eAz_q\000~wYp\0007|0\000TG\$!\t&I||\000\000@4z</5o_\\vw%@.&4)65xMiJuu\000U?Zb+!p:3!oȊIw\$䂼\$\t
a=d@\t(5 \"*}f}᠜:\000'!
PMY@?ozՅdǷ`BCH^UP\0000,`TQbr\000j~1;cLS`\\?vZ\000' 4pz9M憀l
\000\000X*2p`?\\Y6-cK8;Z]=\000w;XM=IStMvW5O}hkN.6?4#Eّ]4L_S5i2=rWh+g.mv]D-7o_z:9f~#p2y38X
cCm\$OBWrmpdgi+Mt\t(Wnp&Z6ʤ}g?^~_
*ן8\000OV|jov-y`{SA)Tz\"-م-tH,XF!G@9I5-iR`k(&>_v+OBTĄ1-\"bJ| RC~9`(FHDDI\000~rmto*ynw5yj=@%c]-+o;yAАE;US@1!;/?S&_o?gN\$j.E~eo\">'O1(C]:7``,!EDDDDlC0\\98dy_ha}Aߗ||Ξҿ
wnܪ
sYbHdz\tި4p`b!Le]cmd`I.)nt#6e/YW#]L;zsLrrZg\\-TB^7
@7P@>'FꝦb1
xHETj_;S1j7T%W{ڢOPnSL!w@YE@2&|^}|rKM_%08
\"1
 ;X<m2Q~_ld\$z}`\t5>Q\000j3SxY`aׄA|>7lcXpxH<,sɉ\000x|28\t9jPF8zKw/1*:@^&}T#\t`cpOgi趜L􂕜T3\000Ə}*(`\t.ŽV3+Ifu?oc]D1kT SKzY}`}<~*}0F;l<#\"\"\":cOGNM1߽v6\000/z~+uW򉣾kř;y6+uhUTTm4mm=Tzϼ!
_GS׃'rm-R^ksw5IBFf&xc_o/t{-62̶H@^M@N<qӰ6Rd#6`6m
\teRwcRl(_)tx\tx2
pz9`k>D
~:?8
=8S#VԲ,<a}jEDDDDD#xրqdVzCvvϞ\000 i)ΐRȠBZmN|%CCAL
Lʴ8@E`00%X:Y>W0#Na
q?`%6h+a@9`Oޱ@]? \"\"\"\"rEG_?>Dg7rt>'WG
?}qE?h+K\$@ɊcY뷓1mBFZ| 5ǷangW2@}
zfչ#}SPן\t\$PKJWPX1j^XJ4&RF3pμ`t7\t_.G.Ky^˷#\"\"\"\":!r!B2=FVn^W9xUdzܶrWZ>Ui%GiTW:}tuwtu%
>=Żá<[t{f\tFO?\$qwzøC,`
|R>3,~Q(ؾB|p\"JW& <ԧo1!%H~*KNA,Z=\tINR@ej\$it5k~\\Ħc]m06tualڕJ#\"\"\"\"\"\"<3{\$\000_XA'@?zoI7L]-)n\$Aׄ}>#@\000IuX\000\\oZ@qr콙vj;^~lϯ]-)hϏ
-
T&!.\000\000\000%tEXtdate:create\0002016-09-14T13:32:39-04:00z\000\000\000%tEXtdate:modify\0002015-06-01T10:37:21-04:00(An\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_2e83ff_256x240.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_2e83ff_256x240.png", "/var/www/mautic-ktn/app/bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_2e83ff_256x240.png");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/b6/b64593d9a17f8ff617a90fe781cb0912.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_2e83ff_256x240.png */
class __TwigTemplate_e61d9a3357eda4c0a923600c844ce6b0 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000IJ\000\000\000gAMA\000\000a\000\000\000 cHRM\000\000z&\000\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000pQ<\000\000,PLTE....................................................................................................):w\000\000\000ctRNS\000XG|\"2wfZNz@@efSFccaMhmzs}䁎]bp
Ιi8*y㧁Xȓد͐ǫ\000\000\000bKGD\000H\000\000\000tIME
%'E\000\000IDATx]c޻\$,'\$h\t)\$uZ7I_B\"H1iRkggdl>ٽ=Y d]زs:w/\tf@e,!A\$HW\t\000O|FMZ ' 1d9 v<AArkeN
fsanl줰.`vbVLtm)u\\vG(\"\"\"\"\"\"8sOp~P¢5{BKF|lAH־QJ,`4.&J'To2bؓlYQI<E`\t
6-XlֈVXH|#j`Eq\000>B:qџC7?xt\000v*ݹ8\000P6_dYJ7%߾A,U4IGb(\000W
pB k.b*X&kVfvZ?k\tyYaRoڨ3DOHnoH6ݩ~
qc2\"\"\"\"\"\"ⲢԎnFb9ͷJ
yj\000JxsjNev'`dU۷ķT_`'yo-/jf>%p}b%gl:`O2Lj-6.`=3`f7ֽuCl!Q8s0x\tvIi)C۷#W\t3{=`DDDDDDg
yURbE:hZ~9јfvv_촸;{%0}z\t{]\tp]\$y>aW,:tXauO<m@RHAb!w(xǰ6 =b%wzRS\t,:3﷤61!\000!!»\\a)yc\$G]?,n7sVun R(D6Cej
)
.t~age\000^z@IR@lsR\"SOaеb}+X\000o(\trX\000=Pl 9+4:Xu\tpL(jW,)l2[0hw3ЇtE#\"\"\"\".2'd2
eFC_7씮KŌ&g~>1X\\!R&HZ%!r
B
hO?pjlgkJ{=`\000\tz*& -!dd\000eAz_q\000~wYp\0007|0\000TG\$!\t&I||\000\000@4z</5o_\\vw%@.&4)65xMiJuu\000U?Zb+!p:3!oȊIw\$䂼\$\t
a=d@\t(5 \"*}f}᠜:\000'!
PMY@?ozՅdǷ`BCH^UP\0000,`TQbr\000j~1;cLS`\\?vZ\000' 4pz9M憀l
\000\000X*2p`?\\Y6-cK8;Z]=\000w;XM=IStMvW5O}hkN.6?4#Eّ]4L_S5i2=rWh+g.mv]D-7o_z:9f~#p2y38X
cCm\$OBWrmpdgi+Mt\t(Wnp&Z6ʤ}g?^~_
*ן8\000OV|jov-y`{SA)Tz\"-م-tH,XF!G@9I5-iR`k(&>_v+OBTĄ1-\"bJ| RC~9`(FHDDI\000~rmto*ynw5yj=@%c]-+o;yAАE;US@1!;/?S&_o?gN\$j.E~eo\">'O1(C]:7``,!EDDDDlC0\\98dy_ha}Aߗ||Ξҿ
wnܪ
sYbHdz\tި4p`b!Le]cmd`I.)nt#6e/YW#]L;zsLrrZg\\-TB^7
@7P@>'FꝦb1
xHETj_;S1j7T%W{ڢOPnSL!w@YE@2&|^}|rKM_%08
\"1
 ;X<m2Q~_ld\$z}`\t5>Q\000j3SxY`aׄA|>7lcXpxH<,sɉ\000x|28\t9jPF8zKw/1*:@^&}T#\t`cpOgi趜L􂕜T3\000Ə}*(`\t.ŽV3+Ifu?oc]D1kT SKzY}`}<~*}0F;l<#\"\"\":cOGNM1߽v6\000/z~+uW򉣾kř;y6+uhUTTm4mm=Tzϼ!
_GS׃'rm-R^ksw5IBFf&xc_o/t{-62̶H@^M@N<qӰ6Rd#6`6m
\teRwcRl(_)tx\tx2
pz9`k>D
~:?8
=8S#VԲ,<a}jEDDDDD#xրqdVzCvvϞ\000 i)ΐRȠBZmN|%CCAL
Lʴ8@E`00%X:Y>W0#Na
q?`%6h+a@9`Oޱ@]? \"\"\"\"rEG_?>Dg7rt>'WG
?}qE?h+K\$@ɊcY뷓1mBFZ| 5ǷangW2@}
zfչ#}SPן\t\$PKJWPX1j^XJ4&RF3pμ`t7\t_.G.Ky^˷#\"\"\"\":!r!B2=FVn^W9xUdzܶrWZ>Ui%GiTW:}tuwtu%
>=Żá<[t{f\tFO?\$qwzøC,`
|R>3,~Q(ؾB|p\"JW& <ԧo1!%H~*KNA,Z=\tINR@ej\$it5k~\\Ħc]m06tualڕJ#\"\"\"\"\"\"<3{\$\000_XA'@?zoI7L]-)n\$Aׄ}>#@\000IuX\000\\oZ@qr콙vj;^~lϯ]-)hϏ
-
T&!.\000\000\000%tEXtdate:create\0002016-09-14T13:32:39-04:00z\000\000\000%tEXtdate:modify\0002015-06-01T10:37:21-04:00(An\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_2e83ff_256x240.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_2e83ff_256x240.png", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_2e83ff_256x240.png");
    }
}
